//
//  ICFlashConverter.m
//  InfiniteCanvas
//
//  Created by Markus Mller on 10.02.05.
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

#import "ICFlashConverter.h"

@implementation ICFlashConverter

+ (BOOL) convertPanel: (OCEPanelObject *) panel withDocumentPath: (NSString *) documentPath writeToPath: (NSString *) path;
{
	// get image path and type
	NSString *type = [[[panel panel] path] pathExtension];
	NSString *originalPath = [[panel panel] path];
	NSFileManager *manager = [NSFileManager defaultManager];
	if (![manager fileExistsAtPath: originalPath]) {
		originalPath = [documentPath stringByAppendingPathComponent:[originalPath lastPathComponent]];
		if (![manager fileExistsAtPath: originalPath]) {
			NSLog(@"ICFlashConverter Error (1): Couldn't convert image!");
			return false;
		}
	}
	
	// set arguments
	NSMutableArray *args = [NSMutableArray array];	
    [args addObject: [NSString stringWithFormat: @"-o%@", [path lastPathComponent]]]; // output file
	//[args addObject: @"-z"]; // Use Flash MX (SWF 6) Zlib encoding for the output. The resulting SWF will be smaller, but not playable in Flash Plugins of Version 5 and below.
    [args addObject: @"-v 0"]; // verbos = quiet
	
	// create path2app
	NSBundle *applicationBundle = [NSBundle mainBundle];
	NSString *pathToApplication = nil;
	if (([type caseInsensitiveCompare: @"jpg"] == NSOrderedSame) || ([type caseInsensitiveCompare: @"jpeg"] == NSOrderedSame)) {
		[args addObject: @"-q 80"]; // compression quality, default=60, currently jpg only
		[args addObject: originalPath];
		pathToApplication = [applicationBundle pathForResource:@"jpeg2swf" ofType: nil];
	} else 	if (([type caseInsensitiveCompare: @"gif"] == NSOrderedSame)) {
		[args addObject: originalPath];
		pathToApplication = [applicationBundle pathForResource:@"gif2swf" ofType: nil];
	} else 	if (([type caseInsensitiveCompare: @"png"] == NSOrderedSame)) {
		[args addObject: originalPath];
		pathToApplication = [applicationBundle pathForResource:@"png2swf" ofType: nil];
	} else {
		NSLog(@"ICFlashConverter Error (2): Couldn't convert image!");
		return false;
	}
	
	//NSTask *task = [NSTask launchedTaskWithLaunchPath: pathToApplication arguments: args];
	NSTask *task = [[NSTask alloc] init];
	
	[task setArguments: args];
	[task setLaunchPath: pathToApplication];
	[task setCurrentDirectoryPath: [path stringByDeletingLastPathComponent]];
	[task launch];
	[task waitUntilExit];
	int status = [task terminationStatus];

	if (status == 0) {
		return YES;
	} else {
		return NO;
	}
	
	return NO;
}

/*+ (BOOL) convertPanel: (OCEPanelObject *) panel withDocumentPath: (NSString *) documentPath writeToPath: (NSString *) path;
{
	Ming_setScale(20.0); // could be global
	Ming_useSWFVersion(6);
	Ming_setSWFCompression(-1);
	
	// import image
	NSString *type = [[[panel panel] path] pathExtension];
	NSString *originalPath = [[panel panel] path];
	NSFileManager *manager = [NSFileManager defaultManager];
	if (![manager fileExistsAtPath: originalPath]) {
		originalPath = [documentPath stringByAppendingPathComponent:[originalPath lastPathComponent]];
		if (![manager fileExistsAtPath: originalPath]) {
			NSLog(@"Couldn't load image!");
			return false;
		}
	}
		
	SWFBitmap bitmap;
	if (([type caseInsensitiveCompare: @"jpg"] == NSOrderedSame) || ([type caseInsensitiveCompare: @"jpeg"] == NSOrderedSame)) {
		FILE *filePointer = fopen([originalPath cString],"r+");
		if (filePointer == nil)
			return false;
		SWFInput input = newSWFInput_file(filePointer);
		bitmap = newSWFBitmap_fromInput(input);
		fclose(filePointer);
		return true;
	} else 	if (([type caseInsensitiveCompare: @"gif"] == NSOrderedSame)) {
		bitmap = (SWFBitmap) newSWFDBLBitmapData_fromGifFile([originalPath cString]);
	} else 	if (([type caseInsensitiveCompare: @"png"] == NSOrderedSame)) {
		bitmap = (SWFBitmap) newSWFDBLBitmapData_fromPngFile([originalPath cString]);
	} else {
		NSLog(@"ICFlashConverter: Couldn't load image!");
		return false;
	}

	if (bitmap == nil) {
		return false;
	}
	
	// create movie
	SWFMovie movie = newSWFMovie();
	SWFMovie_add(movie, (SWFBlock) bitmap);
	SWFMovie_setDimension(movie, [panel bounds].size.width, [panel bounds].size.height);

	SWFMovie_save(movie, [path cString]);
	destroySWFBitmap(bitmap);
	destroySWFMovie(movie);
	//Ming_collectGarbage();?????
	return true;
}*/

+ (BOOL) convertTrail: (OCETrailObject *) panel writeToPath: (NSString *) path;
{
	
	return true;
}


@end
