//  InfiniteCanvas
//
//  Created by Markus Mueller <markus@mindnode.com>.
//	http://www.infinitecanvas.com/
//  Copyright (c) 2003-2005 Markus Mueller. All rights reserved.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//  
#import <Cocoa/Cocoa.h>

@class OCEDocument;
@class OCEWindowController;
@class OCEPanel;
@class OCEObject;
@class OCESliderView;
@class OCEModeView;
@class OCEPanelObject;
@class OCETrailObject;
@class OCENavFrameObject;
@class OCENavTrailObject;
@class OCEPathObject;
@class OCERectObject;
@class OCENavFrameObject;
@class OCECanvasTabView;

@interface OCECanvas : NSView
{
    IBOutlet OCEDocument *document;
    IBOutlet OCEWindowController *controller;
    IBOutlet OCESliderView *sliderView;
    IBOutlet OCEModeView *modeView;


    // global stuff
    NSMutableArray *selectedObjects;
    NSMutableArray *fakePasteBoard;
    bool spaceIsPressed;
    
    // canvas attributes
    float scale;
    NSRect canvasRect;
	BOOL showNavigation;

        
    int displayMode; // 0: edit mode 1: play mode
    int editMode; // 0: select 1: draw trail 2: draw rect 3: move canvas
    
    // drop location indikator
    bool dragging;
    
    // used in several ways when we use mouse events
    NSRect selectRect;
    bool selecting;
	NSTrackingRectTag trackingRect;
    
    // Trail Stuff
    NSBezierPath *rubberBand;
	OCERectObject *focusRingObject;
	OCEPathObject *newPath;
	
    NSNotificationCenter *nc; //notification
}

- (void)setWindowController:(OCEWindowController *)aController;
- (OCEWindowController *)windowController;
- (OCEDocument *)document;
- (void) updateView: (NSNotification *)notification;
- (void) didUndo: (NSNotification *)notification;

// ----------------------------------------------------------------------
// Display/Edit Mode Methoden
// ----------------------------------------------------------------------
- (void) setDisplayMode: (int) flag;
- (int) displayMode;

- (void) setEditMode: (int) flag;
- (int) editMode;

// ----------------------------------------------------------------------
// Scale Canvas
// ----------------------------------------------------------------------
- (void) scaleCanvas: (float) newFactor;
- (float) scaleCanvasFactor;

// ----------------------------------------------------------------------
// Canvas Methoden
// ----------------------------------------------------------------------
- (void) drawEditMode:(NSRect)rect;
- (void) drawNavigationMode:(NSRect)rect;
- (void) drawObjectsInRect: (NSRect) rect;
- (void) drawNavigationObjectsInRect: (NSRect) rect;

- (void) setShowNavigation: (int) flag;

- (void) updateCanvasRect:(NSRect) rect;
- (NSRect) canvasRect;
- (NSPoint) convertPointToView: (NSPoint) aPoint;
- (NSRect) convertRectToView: (NSRect) aRect;
- (NSPoint) convertPointToModel: (NSPoint) aPoint;
- (NSRect) convertRectToModel: (NSRect) aRect;
- (OCERectObject *) checkForFocusRingObject: (NSPoint)point isStartPoint:(bool) startPoint;
- (OCEObject *) objectUnderPoint:(NSPoint)point;
- (bool) draggingInProgress;

// ----------------------------------------------------------------------
// Select Methoden
// ----------------------------------------------------------------------
- (NSMutableArray *) selectedObjects;
- (BOOL)objectIsSelected:(OCEObject *)object;
- (void)selectObject:(OCEObject *)object;
- (void)deselectObject:(OCEObject *)object;
- (void)clearSelection;
- (bool) objectsAreSelected;


// ----------------------------------------------------------------------
// Grid Methoden
// ----------------------------------------------------------------------
- (void) drawGridInRect: (NSRect) rect;
- (NSPoint) gridPoint: (NSPoint) aPoint;

// ----------------------------------------------------------------------
// Mouse Tracking Methoden
// ----------------------------------------------------------------------
- (void)selectAndTrackMouseWithEvent:(NSEvent *)theEvent;
- (void)moveCanvasWithEvent:(NSEvent *)theEvent;
- (void)selectObjectsWithEvent:(NSEvent *)theEvent;
- (void)moveSelectedObjectsWithEvent:(NSEvent *)theEvent;
- (void)trackKnob:(int)knob ofObject:(OCEObject *)object withEvent:(NSEvent *)theEvent;
- (void)createFrameWithEvent: (NSEvent *) theEvent;
- (void)createPathWithEvent: (NSEvent *) theEvent;

// ----------------------------------------------------------------------
// UI-Menu Methoden
// ----------------------------------------------------------------------
- (IBAction)delete:(id)sender;
- (IBAction)selectVisible:(id)sender;
- (IBAction)selectNone:(id)sender;
- (void) keyStrokeEffektingXBy: (float) x yBy: (float) y;

@end
