//
//  OCEDocument.h
//  InfiniteCanvas
//
//  Created by Markus Mueller <markus@mindnode.com>.
//	http://www.infinitecanvas.com/
//  Copyright (c) 2003-2005 Markus Mueller. All rights reserved.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#import <Foundation/Foundation.h>
@class OCEPanel, OCEWindowController, OCEObject, OCETrailObject, OCENavFrameObject, OCEPanelView, OCERectObject;

@interface OCEDocument : NSDocument {
    OCEWindowController *windowController; // hauptfenster
    NSMutableArray *panels; // image objekte 
    NSMutableArray *canvasObjects; // alle objekte die sich auf dem canvas befinden
    NSMutableArray *navigationObjects;
    NSNotificationCenter *nc;
    int panelIDCount;
    int rectObjectIDCount;
    NSColor *canvasColor;
    NSUndoManager *undoManager;
    NSImage *arrowImage;
    NSString *arrowImagePath;
    int navigationTool;
	bool navigationButtons;
	bool firstNavFrame;
	bool activeComponentHint;
	bool scaleCanvas;
	
	// grid attributes
    int gridSize;
    int showGrid;
    int snapToGrid;
    NSColor *gridColor;	
	
	// previewPath
	NSString *previewPath;
}

- (OCEWindowController *) windowController;

// ----------------------------------------------------------------------
// Load and Save
// ----------------------------------------------------------------------
- (NSMutableArray *) dataRepresentation;
- (void) loadDocumentFromArray:(NSArray *) dictionary;

// ----------------------------------------------------------------------
// Panels
// ----------------------------------------------------------------------
- (bool)loadImagesFromPaths:(NSArray *)fileNames;
- (NSMutableArray *)getPanels;
- (void)setPanels:(NSArray *)newPanels;
- (void)insertPanel:(OCEPanel *)panel atIndex:(int)index;
- (void)removePanelAtIndex:(int)index;
- (void)removePanel:(OCEPanel *)object;
- (int)panelCount;
- (OCEPanel *) panelFromID: (int) panelID;
- (OCEPanel *) panelFromPath: (NSString *) filename;
- (bool) panelExistsOnCanvas: (OCEPanel *) panel;

// ----------------------------------------------------------------------
// Canvas Objects
// ----------------------------------------------------------------------
- (NSMutableArray *)canvasObjects;
- (void) addCanvasObject: (OCEObject *)object;
- (void) addCanvasObject: (OCEObject *)object atIndex: (int)index;
- (void) removeCanvasObject: (OCEObject *)object;
- (void) removeCanvasObjectAtIndex: (int)index;
- (int) newRectObjectID;
- (OCERectObject *) rectObjectFromID: (int) rectID;

// ----------------------------------------------------------------------
// Navigation Objects
// ----------------------------------------------------------------------
- (NSMutableArray *) navigationObjects;
- (void) addNavigationObject: (OCEObject *)object;
- (void) addNavigationObject: (OCEObject *)object atIndex: (int)index;
- (void) removeNavigationObject: (OCEObject *)object;
- (void) removeNavigationObjectAtIndex: (int)index;
- (void) removeUnassociatedNavigationTrails;

// ----------------------------------------------------------------------
// LAYER
// ----------------------------------------------------------------------
- (void) moveObjectUp:(OCEObject *)object;
- (void) moveObjectTop:(OCEObject *)object;
- (void) moveObjectsTop:(NSArray *)objects;
- (void) moveObjectDown:(OCEObject *)object;
- (void) moveObjectBottom:(OCEObject *)object;
- (void) moveObjectsBottom:(NSArray *)objects;

// ----------------------------------------------------------------------
// CANVAS
// ----------------------------------------------------------------------
- (NSColor *) canvasColor;
- (void) setCanvasColor: (NSColor *) newColor;


// ----------------------------------------------------------------------
// Trails
// ----------------------------------------------------------------------
- (NSImage *) arrowImage;
- (NSString *) arrowImagePath;
/*- (void) setArrowImageWithPath: (NSString *) path;*/

// ----------------------------------------------------------------------
// Navigation
// ----------------------------------------------------------------------
- (void) setNavigationTool: (int) tool;
- (int) navigationTool;
- (void) setNavigationButtons: (bool) flag;
- (bool) navigationButtons;
- (void) setActiveComponentHint: (bool) flag;
- (bool) activeComponentHint;
- (void) resetNavigationStartFrame;
- (void) setNavigationStartFrame;
- (OCENavFrameObject *) startFrame;
- (int) startFrameID;
- (void) setScaleCanvas: (BOOL) flag;
- (BOOL) scaleCanvas;

// ----------------------------------------------------------------------
// Grid
// ----------------------------------------------------------------------

- (int) gridSize;
- (void) setGridSize: (int) newSize;
- (int) showGrid;
- (void) setShowGrid: (int) flag;
- (int) snapToGrid;
- (void) setSnapToGrid: (int) flag;
- (NSColor *) gridColor;
- (void) setGridColor: (NSColor *) newColor;

// ----------------------------------------------------------------------
// Other
// ----------------------------------------------------------------------
- (NSString *) previewPath;
- (bool) autoGenerateNavigationFrameNavigation: (int) frameWidth;

// ----------------------------------------------------------------------
// Flash
// ----------------------------------------------------------------------
- (void) exportFlashTo: (NSString *) destinationPath;


@end
