//
//  OCEObject.h
//  InfiniteCanvas
//
//  Created by Markus Mueller <markus@mindnode.com>.
//	http://www.infinitecanvas.com/
//  Copyright (c) 2003-2005 Markus Mueller. All rights reserved.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//  
#import <Foundation/Foundation.h>
@class OCECanvas;
@class OCEPanel;
@class OCEDocument;

@interface OCEObject : NSObject <NSCopying> {
    bool locked;
    bool snapAble;
    bool editingObject;
	SEL manipulationSelector;
	id manipulationData;
    NSRect bounds;
    NSUndoManager *undoManager;
    NSNotificationCenter *nc;
}

// draw
- (void) drawObjectIsSelected: (bool) selected;
- (void) drawObjectWithFraction: (float) fraction isSelected: (bool) selected;

// hit tests und knobs 
- (bool) intersectObject: (OCEObject *)object;
- (bool) intersectsRect: (NSRect) rect;
- (int) hitTest: (NSPoint)aPoint isSelected: (bool) isSelected;
- (enum corner) movingKnob: (enum corner) knob fromPoint: (NSPoint) lastPoint toPoint: (NSPoint) point 
				 withEvent: (NSEvent *) theEvent;
+ (int)flipKnob:(int)knob horizontal:(BOOL)horizFlag;
- (void) doubleKlickAtPoint: (NSPoint) aPoint;
- (NSPoint) pointForKnob: (enum corner) knob;

// attributes 
- (bool) locked;
- (void) setLocked:(bool) flag;
- (bool) snapAble;
- (void) setSnapAble: (bool) flag;
- (bool) editingObject;
- (void) startManipulationWithSelector:(SEL)aSelector andData: (id) data;
- (void) stopManipulation;
- (void) moveXBy: (double) moveX moveYBy: (double) moveY;
- (NSPoint) origin;
- (NSUndoManager *) undoManager;
- (void) setUndoManager: (NSUndoManager *) newUndoManager;
- (NSRect) bounds;
- (void) addedToCanvas: (OCEDocument *) document;
- (void) removedFromCanvas: (OCEDocument *) document;
- (NSBezierPath *) path;
- (void) gridObject: (int) gridSize;
+ (NSPoint) gridPoint: (NSPoint) aPoint withGridSize: (int) gridSize;


// save/load
- (NSMutableArray *) dataRepresentation;
+ (id) objectFromArray: (NSArray *) array forDocument: (OCEDocument *) document;
- (id)initWithContentsOfArray:(NSArray *) array forDocument: (OCEDocument *) newDocument;
- (NSString *) exportFlash: (NSString *) flashPath documentPath: (NSString *) documentPath;
- (NSString *) exportFlash;
@end
